@@ -1,4 +1,4 @@
-/* Copyright (c) 1997-2019
+/* Copyright (c) 1997-2020
    Ewgenij Gawrilow, Michael Joswig, and the polymake team
    Technische Universität Berlin, Germany
    https://polymake.org
@@ -22,18 +22,18 @@
 namespace polymake { namespace polytope {
 
 template <typename Scalar>
-perl::Object bound(perl::Object p_in)
+BigObject bound(BigObject p_in)
 {
    const bool is_positive=p_in.give("POSITIVE");
    if (!is_positive)
       throw std::runtime_error("polyhedron must be positive");
 
-   const int d=p_in.call_method("AMBIENT_DIM");
+   const Int d = p_in.call_method("AMBIENT_DIM");
 
    SparseMatrix<Scalar> tau=unit_matrix<Scalar>(d+1);
    tau.col(0).fill(1);
 
-   perl::Object p_out=transform<Scalar>(p_in, tau);
+   BigObject p_out=transform<Scalar>(p_in, tau);
    p_out.set_description() << "Bounded polytope transformed from " << p_in.name() << endl;
 
    p_out.take("BOUNDED") << true;
